# eric7.Plugins.VcsPlugins.vcsGit.GitNewProjectOptionsDialog

Module implementing the Git Options Dialog for a new project from the repository.

### Global Attributes

None

### Classes

GitNewProjectOptionsDialog | Class implementing the Options Dialog for a new project from the repository.

### Functions

None

## GitNewProjectOptionsDialog

Class implementing the Options Dialog for a new project from the repository.

### Derived from

QDialog, Ui_GitNewProjectOptionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitNewProjectOptionsDialog | Constructor
__saveHistory | Private method to save the repository URL history.
getData | Public slot to retrieve the data entered into the dialog.
on_projectDirButton_clicked | Private slot to display a directory selection dialog.
on_vcsProjectDirEdit_textChanged | Private slot to handle a change of the project directory.
on_vcsUrlButton_clicked | Private slot to display a selection dialog.
on_vcsUrlClearHistoryButton_clicked | Private slot to clear the history of entered repository URLs.
on_vcsUrlCombo_editTextChanged | Private slot to handle changes of the URL.

### Static Methods

None

#### GitNewProjectOptionsDialog (Constructor)

GitNewProjectOptionsDialog(vcs, parent=None)

Constructor

vcs
  reference to the version control object
parent
  parent widget (QWidget)

#### GitNewProjectOptionsDialog.__saveHistory

__saveHistory()

Private method to save the repository URL history.

#### GitNewProjectOptionsDialog.getData

getData()

Public slot to retrieve the data entered into the dialog.

Return:
  a tuple of a string (project directory) and a dictionary containing the data entered.

#### GitNewProjectOptionsDialog.on_projectDirButton_clicked

on_projectDirButton_clicked()

Private slot to display a directory selection dialog.

#### GitNewProjectOptionsDialog.on_vcsProjectDirEdit_textChanged

on_vcsProjectDirEdit_textChanged(txt)

Private slot to handle a change of the project directory.

txt
  name of the project directory (string)

#### GitNewProjectOptionsDialog.on_vcsUrlButton_clicked

on_vcsUrlButton_clicked()

Private slot to display a selection dialog.

#### GitNewProjectOptionsDialog.on_vcsUrlClearHistoryButton_clicked

on_vcsUrlClearHistoryButton_clicked()

Private slot to clear the history of entered repository URLs.

#### GitNewProjectOptionsDialog.on_vcsUrlCombo_editTextChanged

on_vcsUrlCombo_editTextChanged(txt)

Private slot to handle changes of the URL.

txt (str)
  current text of the combo box

Up